.TH pipe n 4.1 "Tcl-Extensions"
.HS pipe tcl
.BS

.SH NAME
pipe \- Create a standalone pipe

.SH SYNOPSIS
\fBpackage require pipe\fR 
.br
\fBset\fR fds [\fBpipe\fR]
.br
\fBset\fR fread  [\fBlindex \fR$fds] 0
.br
\fBset\fR fwrite [\fBlindex \fR$fds] 1

.SH DESCRIPTION

.PP
This package is an implementation of TIP #304 by Alexandre Ferrieux
(incorporated into Tcl 8.6) turned into a separate Tcl extension.
The \fBpipe\fR command first appeared in the \fBTclx\fR extension.
.PP
After loading it creates the command \fBpipe\fR in the root namespace.
This command behaves the same way as \fBchan pipe\fR command
described by the TIP #304.
.PP
The \fBpipe\fR command creates a standalone pipe whose read- and
write-side channels are returned as a two-element list, the first element
being the read side and the second the write side. Can be useful e.g. to
redirect separately stderr and stdout from a subprocess. To do this,
spawn with "2>@" or ">@" redirection operators onto the write side of a
pipe, and then immediately close it in the parent. This is necessary to
get an EOF on the read side once the child has exited or otherwise
closed its output. 

.SH EXAMPLES

.PP
Here's the sample code showing how to run a process, write something
to its stdin and then close it making the process exit, and
collecting stdout of the process:

.PP
\fBforeach\fR {ir iw} [\fBpipe\fR] \fBbreak\fR
.br
\fBforeach\fR {or ow} [\fBpipe\fR] \fBbreak\fR
.br
\fBexec\fR someprogram <@$ir >@$ow 2>&1
.br
\fBputs\fR $iw "some command"
.br
\fBclose\fR $ir
.br
\fBset\fR result [\fBread\fR $or]
.br
\fBclose\fR $iw; \fBclose\fR $or; \fBclose\fR $ow

.SH SEE ALSO

TIP #304: http://www.tcl.tk/cgi-bin/tct/tip/304.html
.br
Tclx: http://sourceforge.net/projects/Tclx

.SH AUTHORS

.PP
The code is written by
Alexandre Ferrieux <alexandre.ferrieux@gmail.com>
.PP
The package is created by
Konstantin Khomoutov <flatworm@users.sourceforge.net>

