#include <tcl.h>
#include "tclpipe.h"

/*
 *----------------------------------------------------------------------
 *
 * ChanPipeObjCmd --
 *
 *	This function is invoked to process the "chan pipe" Tcl command.
 *	See the user documentation for details on what it does.
 *
 * Results:
 *	A standard Tcl result.
 *
 * Side effects:
 *	Creates a pair of Tcl channels wrapping both ends of a new
 *	anonymous pipe.
 *
 *----------------------------------------------------------------------
 */

static int
ChanPipeObjCmd(
    ClientData dummy,		/* Not used. */
    Tcl_Interp *interp,		/* Current interpreter. */
    int objc,			/* Number of arguments. */
    Tcl_Obj *const objv[])	/* Argument objects. */
{
    Tcl_Channel   rchan,wchan;
    const char *channelNames [2];
	Tcl_Obj *resultPtr;
	
    if (objc != 1) {
		Tcl_WrongNumArgs(interp, 1, objv, "");
		return TCL_ERROR;
    }
	
    if (Tcl_CreatePipe (interp, &rchan, &wchan, 0) != TCL_OK)
        return TCL_ERROR;
	
    channelNames [0] = Tcl_GetChannelName (rchan);
    channelNames [1] = Tcl_GetChannelName (wchan);
	
	resultPtr = Tcl_NewObj();
	Tcl_ListObjAppendElement(NULL, resultPtr, Tcl_NewStringObj(channelNames[0],-1));
	Tcl_ListObjAppendElement(NULL, resultPtr, Tcl_NewStringObj(channelNames[1],-1));
	Tcl_SetObjResult(interp, resultPtr);

    return TCL_OK;
}

/*
 *----------------------------------------------------------------------
 *
 * Pipe_Init --
 *
 *	Initialize the new package "pipe".
 *
 * Results:
 *	A standard Tcl result
 *
 * Side effects:
 *	The "pipe" package is created.
 *	One new command "pipe" is added to the Tcl interpreter.
 *
 *----------------------------------------------------------------------
 */

#ifdef BUILD_pipe
#undef TCL_STORAGE_CLASS
#define TCL_STORAGE_CLASS DLLEXPORT
#endif /* BUILD_pipe */

EXTERN int
Pipe_Init(Tcl_Interp *interp)
{
    if (Tcl_InitStubs(interp, "8.1", 0) == NULL) {
    return TCL_ERROR;
    }
    if (Tcl_PkgRequire(interp, "Tcl", "8.1", 0) == NULL) {
	return TCL_ERROR;
    }
    if (Tcl_PkgProvide(interp, PACKAGE_NAME, PACKAGE_VERSION) != TCL_OK) {
	return TCL_ERROR;
    }
    Tcl_CreateObjCommand(interp, "pipe",
        (Tcl_ObjCmdProc *) ChanPipeObjCmd,
	    (ClientData)NULL, (Tcl_CmdDeleteProc *)NULL);

    return TCL_OK;
}

